# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion

class TestKnowledgeAssertion(unittest.TestCase):
    """KnowledgeAssertion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeAssertion:
        """Test KnowledgeAssertion
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeAssertion`
        """
        model = KnowledgeAssertion()
        if include_optional:
            return KnowledgeAssertion(
                assertion_id = 56,
                client_id = '',
                confidence = 1.337,
                created_at = '',
                predicate = '',
                source_artifact_id = 56,
                source_kind = '',
                source_ref = '',
                status = '',
                subject_entity_id = '',
                valid_from = '',
                valid_to = '',
                value_json = None
            )
        else:
            return KnowledgeAssertion(
        )
        """

    def testKnowledgeAssertion(self):
        """Test KnowledgeAssertion"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_recommend_presets_response import OrganizationsRecommendPresetsResponse

class TestOrganizationsRecommendPresetsResponse(unittest.TestCase):
    """OrganizationsRecommendPresetsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsRecommendPresetsResponse:
        """Test OrganizationsRecommendPresetsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsRecommendPresetsResponse`
        """
        model = OrganizationsRecommendPresetsResponse()
        if include_optional:
            return OrganizationsRecommendPresetsResponse(
                error = '',
                org_guid = '',
                recommendations = [
                    neurograph.v1.models.organizations/preset_recommendation.organizations.PresetRecommendation(
                        match_reason = '', 
                        match_score = 1.337, 
                        preset_id = '', 
                        preset_name = '', 
                        recommendation_metadata = [
                            56
                            ], )
                    ]
            )
        else:
            return OrganizationsRecommendPresetsResponse(
        )
        """

    def testOrganizationsRecommendPresetsResponse(self):
        """Test OrganizationsRecommendPresetsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
